<?php

namespace Drupal\node_by_email\Commands;

use Drush\Commands\DrushCommands;
use Drupal\node_by_email\IMAPService;
use \Drupal\node_by_email\MidToNodeService;

/**
 * A Drush commandfile.
 *
 * In addition to this file, you need a drush.services.yml
 * in root of your module, and a composer.json file that provides the name
 * of the services file to use.
 *
 * See these files for an example of injecting Drupal services:
 *   - http://cgit.drupalcode.org/devel/tree/src/Commands/DevelCommands.php
 *   - http://cgit.drupalcode.org/devel/tree/drush.services.yml
 */
class NodeByEmailCommands extends DrushCommands {

  /**
   * Drupal\node_by_email\IMAPService definition.
   *
   * @var \Drupal\node_by_email\IMAPService
   */
  protected $nodeByEmailImapConnection;

  /**
   * Node by email mid to node service.
   *
   * @var \Drupal\node_by_email\MidToNodeService
   */
  protected $midToNodeService;

  public function __construct(IMAPService $imap, MidToNodeService $midToNodeService,) {
      $this->nodeByEmailImapConnection = $imap;
      $this->midToNodeService = $midToNodeService;
    }

  /**
   * This command generates nodes from mid.
   *
   * @command node_by_email:generate_node
   * @aliases nbe-gn
   */
  public function commandName() {
    $emailArray = $this->nodeByEmailImapConnection->getUnseenEmailList();
    if (!empty($emailArray)) {
      foreach ($emailArray as $mid) {
        $this->midToNodeService->createNodeFromMid($mid);
        $this->output()->writeln('creating node for mid: ' . $mid);
      }
    }
    else {
      $this->output()->writeln('No unseen email found.');
    }
  }

}
